﻿#version 330 core

out vec4 FragColor;

in vec3 TexCoords;

uniform vec3 _SunDirection;

uniform vec3 _GroundColor;
uniform vec3 _SkyHorizonColor;
uniform vec3 _SkyZenithColor;

uniform float _SunFocus;
uniform float _SunIntensity;

vec4 GetSkyValue(vec3 rayDirection)
{
	float skyGradientT = pow(smoothstep(0, 0.4, rayDirection.y), 0.35);
	vec3 skyGradient = mix(_SkyHorizonColor, _SkyZenithColor, skyGradientT);
	float sun = pow(max(0, dot(rayDirection, -_SunDirection)), _SunFocus) * _SunIntensity;
	
	float groundToSkyT = smoothstep(-0.01, 0, rayDirection.y);
	float sunMask = (groundToSkyT >= 1 ? 1 : 0);
	return vec4(mix(_GroundColor, skyGradient, groundToSkyT) + sun * sunMask, 1.0);
}

void main()
{
    FragColor = GetSkyValue(normalize(TexCoords));
}